==> haskell-text-zipper-0.13-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-G0nlWu7tX7PKjYVJs9rxqi
key:                  text-zipper-0.13-G0nlWu7tX7PKjYVJs9rxqi
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  446e315ddc4b867e88a4a7318a0eb629
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-G0nlWu7tX7PKjYVJs9rxqi
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-B5pfN7kp2sVHpMWItbJQ58

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.13-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-A6qqwFtc4MR8YqVFUlZUua
key:                  text-zipper-0.13-A6qqwFtc4MR8YqVFUlZUua
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  322213aaf7b23ce74d5f66c8e13aefbd
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-A6qqwFtc4MR8YqVFUlZUua
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-2If6MrCrP3g55Bnhb5dowG

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
